package com.google.zxing.datamatrix.encoder;

import com.google.zxing.Dimension;
import java.util.Arrays;

public final class HighLevelEncoder {
    static final int ASCII_ENCODATION = 0;
    static final int BASE256_ENCODATION = 5;
    static final int C40_ENCODATION = 1;
    static final char C40_UNLATCH = 254;
    static final int EDIFACT_ENCODATION = 4;
    static final char LATCH_TO_ANSIX12 = 238;
    static final char LATCH_TO_BASE256 = 231;
    static final char LATCH_TO_C40 = 230;
    static final char LATCH_TO_EDIFACT = 240;
    static final char LATCH_TO_TEXT = 239;
    private static final char MACRO_05 = 236;
    private static final String MACRO_05_HEADER = "[)>\u001e05\u001d";
    private static final char MACRO_06 = 237;
    private static final String MACRO_06_HEADER = "[)>\u001e06\u001d";
    private static final String MACRO_TRAILER = "\u001e\u0004";
    private static final char PAD = 129;
    static final int TEXT_ENCODATION = 2;
    static final char UPPER_SHIFT = 235;
    static final int X12_ENCODATION = 3;
    static final char X12_UNLATCH = 254;

    static boolean isDigit(char c) {
        return c >= '0' && c <= '9';
    }

    static boolean isExtendedASCII(char c) {
        return c >= 128 && c <= 255;
    }

    private static boolean isNativeC40(char c) {
        return c == ' ' || (c >= '0' && c <= '9') || (c >= 'A' && c <= 'Z');
    }

    private static boolean isNativeEDIFACT(char c) {
        return c >= ' ' && c <= '^';
    }

    private static boolean isNativeText(char c) {
        return c == ' ' || (c >= '0' && c <= '9') || (c >= 'a' && c <= 'z');
    }

    private static boolean isSpecialB256(char c) {
        return false;
    }

    private static boolean isX12TermSep(char c) {
        return c == '\r' || c == '*' || c == '>';
    }

    private HighLevelEncoder() {
    }

    private static char randomize253State(char c, int i) {
        int i2 = c + ((i * 149) % 253) + C40_ENCODATION;
        if (i2 > 254) {
            i2 -= 254;
        }
        return (char) i2;
    }

    public static String encodeHighLevel(String str) {
        return encodeHighLevel(str, SymbolShapeHint.FORCE_NONE, null, null);
    }

    public static String encodeHighLevel(String str, SymbolShapeHint symbolShapeHint, Dimension dimension, Dimension dimension2) {
        int i = 0;
        Encoder[] encoderArr = {new ASCIIEncoder(), new C40Encoder(), new TextEncoder(), new X12Encoder(), new EdifactEncoder(), new Base256Encoder()};
        EncoderContext encoderContext = new EncoderContext(str);
        encoderContext.setSymbolShape(symbolShapeHint);
        encoderContext.setSizeConstraints(dimension, dimension2);
        if (str.startsWith(MACRO_05_HEADER) && str.endsWith(MACRO_TRAILER)) {
            encoderContext.writeCodeword(MACRO_05);
            encoderContext.setSkipAtEnd(TEXT_ENCODATION);
            encoderContext.pos += 7;
        } else if (str.startsWith(MACRO_06_HEADER) && str.endsWith(MACRO_TRAILER)) {
            encoderContext.writeCodeword(MACRO_06);
            encoderContext.setSkipAtEnd(TEXT_ENCODATION);
            encoderContext.pos += 7;
        }
        while (encoderContext.hasMoreCharacters()) {
            encoderArr[i].encode(encoderContext);
            if (encoderContext.getNewEncoding() >= 0) {
                i = encoderContext.getNewEncoding();
                encoderContext.resetEncoderSignal();
            }
        }
        int codewordCount = encoderContext.getCodewordCount();
        encoderContext.updateSymbolInfo();
        int dataCapacity = encoderContext.getSymbolInfo().getDataCapacity();
        if (!(codewordCount >= dataCapacity || i == 0 || i == BASE256_ENCODATION || i == EDIFACT_ENCODATION)) {
            encoderContext.writeCodeword(254);
        }
        StringBuilder codewords = encoderContext.getCodewords();
        if (codewords.length() < dataCapacity) {
            codewords.append(PAD);
        }
        while (codewords.length() < dataCapacity) {
            codewords.append(randomize253State(PAD, codewords.length() + C40_ENCODATION));
        }
        return encoderContext.getCodewords().toString();
    }

    static int lookAheadTest(CharSequence charSequence, int i, int i2) {
        float[] fArr;
        char c;
        if (i >= charSequence.length()) {
            return i2;
        }
        if (i2 == 0) {
            fArr = new float[]{0.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.25f};
        } else {
            fArr = new float[]{1.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.25f};
            fArr[i2] = 0.0f;
        }
        int i3 = 0;
        while (true) {
            int i4 = i + i3;
            if (i4 == charSequence.length()) {
                byte[] bArr = new byte[6];
                int[] iArr = new int[6];
                int findMinimums = findMinimums(fArr, iArr, Integer.MAX_VALUE, bArr);
                int minimumCount = getMinimumCount(bArr);
                if (iArr[0] == findMinimums) {
                    return 0;
                }
                if (minimumCount == C40_ENCODATION && bArr[BASE256_ENCODATION] > 0) {
                    return BASE256_ENCODATION;
                }
                if (minimumCount == C40_ENCODATION && bArr[EDIFACT_ENCODATION] > 0) {
                    return EDIFACT_ENCODATION;
                }
                if (minimumCount == C40_ENCODATION && bArr[TEXT_ENCODATION] > 0) {
                    return TEXT_ENCODATION;
                }
                if (minimumCount != C40_ENCODATION || bArr[3] <= 0) {
                    return C40_ENCODATION;
                }
                return 3;
            }
            char charAt = charSequence.charAt(i4);
            i3 += C40_ENCODATION;
            if (isDigit(charAt)) {
                fArr[0] = fArr[0] + 0.5f;
            } else if (isExtendedASCII(charAt)) {
                fArr[0] = (float) Math.ceil((double) fArr[0]);
                fArr[0] = fArr[0] + 2.0f;
            } else {
                fArr[0] = (float) Math.ceil((double) fArr[0]);
                fArr[0] = fArr[0] + 1.0f;
            }
            if (isNativeC40(charAt)) {
                fArr[C40_ENCODATION] = fArr[C40_ENCODATION] + 0.6666667f;
            } else if (isExtendedASCII(charAt)) {
                fArr[C40_ENCODATION] = fArr[C40_ENCODATION] + 2.6666667f;
            } else {
                fArr[C40_ENCODATION] = fArr[C40_ENCODATION] + 1.3333334f;
            }
            if (isNativeText(charAt)) {
                fArr[TEXT_ENCODATION] = fArr[TEXT_ENCODATION] + 0.6666667f;
            } else if (isExtendedASCII(charAt)) {
                fArr[TEXT_ENCODATION] = fArr[TEXT_ENCODATION] + 2.6666667f;
            } else {
                fArr[TEXT_ENCODATION] = fArr[TEXT_ENCODATION] + 1.3333334f;
            }
            if (isNativeX12(charAt)) {
                fArr[3] = fArr[3] + 0.6666667f;
            } else if (isExtendedASCII(charAt)) {
                fArr[3] = fArr[3] + 4.3333335f;
            } else {
                fArr[3] = fArr[3] + 3.3333333f;
            }
            if (isNativeEDIFACT(charAt)) {
                fArr[EDIFACT_ENCODATION] = fArr[EDIFACT_ENCODATION] + 0.75f;
            } else if (isExtendedASCII(charAt)) {
                fArr[EDIFACT_ENCODATION] = fArr[EDIFACT_ENCODATION] + 4.25f;
            } else {
                fArr[EDIFACT_ENCODATION] = fArr[EDIFACT_ENCODATION] + 3.25f;
            }
            if (isSpecialB256(charAt)) {
                c = 5;
                fArr[BASE256_ENCODATION] = fArr[BASE256_ENCODATION] + 4.0f;
            } else {
                c = 5;
                fArr[BASE256_ENCODATION] = fArr[BASE256_ENCODATION] + 1.0f;
            }
            if (i3 >= EDIFACT_ENCODATION) {
                int[] iArr2 = new int[6];
                byte[] bArr2 = new byte[6];
                findMinimums(fArr, iArr2, Integer.MAX_VALUE, bArr2);
                int minimumCount2 = getMinimumCount(bArr2);
                if (iArr2[0] < iArr2[c] && iArr2[0] < iArr2[C40_ENCODATION] && iArr2[0] < iArr2[TEXT_ENCODATION] && iArr2[0] < iArr2[3] && iArr2[0] < iArr2[EDIFACT_ENCODATION]) {
                    return 0;
                }
                if (iArr2[BASE256_ENCODATION] < iArr2[0] || bArr2[C40_ENCODATION] + bArr2[TEXT_ENCODATION] + bArr2[3] + bArr2[EDIFACT_ENCODATION] == 0) {
                    return BASE256_ENCODATION;
                }
                if (minimumCount2 == C40_ENCODATION && bArr2[EDIFACT_ENCODATION] > 0) {
                    return EDIFACT_ENCODATION;
                }
                if (minimumCount2 == C40_ENCODATION && bArr2[TEXT_ENCODATION] > 0) {
                    return TEXT_ENCODATION;
                }
                if (minimumCount2 == C40_ENCODATION && bArr2[3] > 0) {
                    return 3;
                }
                if (iArr2[C40_ENCODATION] + C40_ENCODATION < iArr2[0] && iArr2[C40_ENCODATION] + C40_ENCODATION < iArr2[BASE256_ENCODATION] && iArr2[C40_ENCODATION] + C40_ENCODATION < iArr2[EDIFACT_ENCODATION] && iArr2[C40_ENCODATION] + C40_ENCODATION < iArr2[TEXT_ENCODATION]) {
                    if (iArr2[C40_ENCODATION] < iArr2[3]) {
                        return C40_ENCODATION;
                    }
                    if (iArr2[C40_ENCODATION] == iArr2[3]) {
                        for (int i5 = i + i3 + C40_ENCODATION; i5 < charSequence.length(); i5 += C40_ENCODATION) {
                            char charAt2 = charSequence.charAt(i5);
                            if (isX12TermSep(charAt2)) {
                                return 3;
                            }
                            if (!isNativeX12(charAt2)) {
                                break;
                            }
                        }
                        return C40_ENCODATION;
                    }
                }
            }
        }
    }

    private static int findMinimums(float[] fArr, int[] iArr, int i, byte[] bArr) {
        Arrays.fill(bArr, (byte) 0);
        int i2 = i;
        for (int i3 = 0; i3 < 6; i3 += C40_ENCODATION) {
            iArr[i3] = (int) Math.ceil((double) fArr[i3]);
            int i4 = iArr[i3];
            if (i2 > i4) {
                Arrays.fill(bArr, (byte) 0);
                i2 = i4;
            }
            if (i2 == i4) {
                bArr[i3] = (byte) (bArr[i3] + 1);
            }
        }
        return i2;
    }

    private static int getMinimumCount(byte[] bArr) {
        int i = 0;
        for (int i2 = 0; i2 < 6; i2 += C40_ENCODATION) {
            i += bArr[i2];
        }
        return i;
    }

    private static boolean isNativeX12(char c) {
        return isX12TermSep(c) || c == ' ' || (c >= '0' && c <= '9') || (c >= 'A' && c <= 'Z');
    }

    public static int determineConsecutiveDigitCount(CharSequence charSequence, int i) {
        int length = charSequence.length();
        int i2 = 0;
        if (i < length) {
            char charAt = charSequence.charAt(i);
            while (isDigit(charAt) && i < length) {
                i2 += C40_ENCODATION;
                i += C40_ENCODATION;
                if (i < length) {
                    charAt = charSequence.charAt(i);
                }
            }
        }
        return i2;
    }

    static void illegalCharacter(char c) {
        String hexString = Integer.toHexString(c);
        throw new IllegalArgumentException("Illegal character: " + c + " (0x" + ("0000".substring(0, 4 - hexString.length()) + hexString) + ')');
    }
}
