package com.google.zxing.oned;

import com.google.zxing.BarcodeFormat;
import com.google.zxing.ChecksumException;
import com.google.zxing.DecodeHintType;
import com.google.zxing.FormatException;
import com.google.zxing.NotFoundException;
import com.google.zxing.Result;
import com.google.zxing.ResultPoint;
import com.google.zxing.common.BitArray;
import java.util.ArrayList;
import java.util.Map;

public final class Code128Reader extends OneDReader {
    private static final int CODE_CODE_A = 101;
    private static final int CODE_CODE_B = 100;
    private static final int CODE_CODE_C = 99;
    private static final int CODE_FNC_1 = 102;
    private static final int CODE_FNC_2 = 97;
    private static final int CODE_FNC_3 = 96;
    private static final int CODE_FNC_4_A = 101;
    private static final int CODE_FNC_4_B = 100;
    static final int[][] CODE_PATTERNS = {new int[]{2, 1, 2, 2, 2, 2}, new int[]{2, 2, 2, 1, 2, 2}, new int[]{2, 2, 2, 2, 2, 1}, new int[]{1, 2, 1, 2, 2, 3}, new int[]{1, 2, 1, 3, 2, 2}, new int[]{1, 3, 1, 2, 2, 2}, new int[]{1, 2, 2, 2, 1, 3}, new int[]{1, 2, 2, 3, 1, 2}, new int[]{1, 3, 2, 2, 1, 2}, new int[]{2, 2, 1, 2, 1, 3}, new int[]{2, 2, 1, 3, 1, 2}, new int[]{2, 3, 1, 2, 1, 2}, new int[]{1, 1, 2, 2, 3, 2}, new int[]{1, 2, 2, 1, 3, 2}, new int[]{1, 2, 2, 2, 3, 1}, new int[]{1, 1, 3, 2, 2, 2}, new int[]{1, 2, 3, 1, 2, 2}, new int[]{1, 2, 3, 2, 2, 1}, new int[]{2, 2, 3, 2, 1, 1}, new int[]{2, 2, 1, 1, 3, 2}, new int[]{2, 2, 1, 2, 3, 1}, new int[]{2, 1, 3, 2, 1, 2}, new int[]{2, 2, 3, 1, 1, 2}, new int[]{3, 1, 2, 1, 3, 1}, new int[]{3, 1, 1, 2, 2, 2}, new int[]{3, 2, 1, 1, 2, 2}, new int[]{3, 2, 1, 2, 2, 1}, new int[]{3, 1, 2, 2, 1, 2}, new int[]{3, 2, 2, 1, 1, 2}, new int[]{3, 2, 2, 2, 1, 1}, new int[]{2, 1, 2, 1, 2, 3}, new int[]{2, 1, 2, 3, 2, 1}, new int[]{2, 3, 2, 1, 2, 1}, new int[]{1, 1, 1, 3, 2, 3}, new int[]{1, 3, 1, 1, 2, 3}, new int[]{1, 3, 1, 3, 2, 1}, new int[]{1, 1, 2, 3, 1, 3}, new int[]{1, 3, 2, 1, 1, 3}, new int[]{1, 3, 2, 3, 1, 1}, new int[]{2, 1, 1, 3, 1, 3}, new int[]{2, 3, 1, 1, 1, 3}, new int[]{2, 3, 1, 3, 1, 1}, new int[]{1, 1, 2, 1, 3, 3}, new int[]{1, 1, 2, 3, 3, 1}, new int[]{1, 3, 2, 1, 3, 1}, new int[]{1, 1, 3, 1, 2, 3}, new int[]{1, 1, 3, 3, 2, 1}, new int[]{1, 3, 3, 1, 2, 1}, new int[]{3, 1, 3, 1, 2, 1}, new int[]{2, 1, 1, 3, 3, 1}, new int[]{2, 3, 1, 1, 3, 1}, new int[]{2, 1, 3, 1, 1, 3}, new int[]{2, 1, 3, 3, 1, 1}, new int[]{2, 1, 3, 1, 3, 1}, new int[]{3, 1, 1, 1, 2, 3}, new int[]{3, 1, 1, 3, 2, 1}, new int[]{3, 3, 1, 1, 2, 1}, new int[]{3, 1, 2, 1, 1, 3}, new int[]{3, 1, 2, 3, 1, 1}, new int[]{3, 3, 2, 1, 1, 1}, new int[]{3, 1, 4, 1, 1, 1}, new int[]{2, 2, 1, 4, 1, 1}, new int[]{4, 3, 1, 1, 1, 1}, new int[]{1, 1, 1, 2, 2, 4}, new int[]{1, 1, 1, 4, 2, 2}, new int[]{1, 2, 1, 1, 2, 4}, new int[]{1, 2, 1, 4, 2, 1}, new int[]{1, 4, 1, 1, 2, 2}, new int[]{1, 4, 1, 2, 2, 1}, new int[]{1, 1, 2, 2, 1, 4}, new int[]{1, 1, 2, 4, 1, 2}, new int[]{1, 2, 2, 1, 1, 4}, new int[]{1, 2, 2, 4, 1, 1}, new int[]{1, 4, 2, 1, 1, 2}, new int[]{1, 4, 2, 2, 1, 1}, new int[]{2, 4, 1, 2, 1, 1}, new int[]{2, 2, 1, 1, 1, 4}, new int[]{4, 1, 3, 1, 1, 1}, new int[]{2, 4, 1, 1, 1, 2}, new int[]{1, 3, 4, 1, 1, 1}, new int[]{1, 1, 1, 2, 4, 2}, new int[]{1, 2, 1, 1, 4, 2}, new int[]{1, 2, 1, 2, 4, 1}, new int[]{1, 1, 4, 2, 1, 2}, new int[]{1, 2, 4, 1, 1, 2}, new int[]{1, 2, 4, 2, 1, 1}, new int[]{4, 1, 1, 2, 1, 2}, new int[]{4, 2, 1, 1, 1, 2}, new int[]{4, 2, 1, 2, 1, 1}, new int[]{2, 1, 2, 1, 4, 1}, new int[]{2, 1, 4, 1, 2, 1}, new int[]{4, 1, 2, 1, 2, 1}, new int[]{1, 1, 1, 1, 4, 3}, new int[]{1, 1, 1, 3, 4, 1}, new int[]{1, 3, 1, 1, 4, 1}, new int[]{1, 1, 4, 1, 1, 3}, new int[]{1, 1, 4, 3, 1, 1}, new int[]{4, 1, 1, 1, 1, 3}, new int[]{4, 1, 1, 3, 1, 1}, new int[]{1, 1, 3, 1, 4, 1}, new int[]{1, 1, 4, 1, 3, 1}, new int[]{3, 1, 1, 1, 4, 1}, new int[]{4, 1, 1, 1, 3, 1}, new int[]{2, 1, 1, 4, 1, 2}, new int[]{2, 1, 1, 2, 1, 4}, new int[]{2, 1, 1, 2, 3, 2}, new int[]{2, 3, 3, 1, 1, 1, 2}};
    private static final int CODE_SHIFT = 98;
    private static final int CODE_START_A = 103;
    private static final int CODE_START_B = 104;
    private static final int CODE_START_C = 105;
    private static final int CODE_STOP = 106;
    private static final float MAX_AVG_VARIANCE = 0.25f;
    private static final float MAX_INDIVIDUAL_VARIANCE = 0.7f;

    private static int[] findStartPattern(BitArray bitArray) throws NotFoundException {
        int size = bitArray.getSize();
        int nextSet = bitArray.getNextSet(0);
        int[] iArr = new int[6];
        int length = iArr.length;
        boolean z = false;
        int i = 0;
        int i2 = nextSet;
        while (nextSet < size) {
            if (bitArray.get(nextSet) != z) {
                iArr[i] = iArr[i] + 1;
            } else {
                if (i == length - 1) {
                    float f = MAX_AVG_VARIANCE;
                    int i3 = -1;
                    for (int i4 = CODE_START_A; i4 <= CODE_START_C; i4++) {
                        float patternMatchVariance = patternMatchVariance(iArr, CODE_PATTERNS[i4], MAX_INDIVIDUAL_VARIANCE);
                        if (patternMatchVariance < f) {
                            i3 = i4;
                            f = patternMatchVariance;
                        }
                    }
                    if (i3 < 0 || !bitArray.isRange(Math.max(0, i2 - ((nextSet - i2) / 2)), i2, false)) {
                        i2 += iArr[0] + iArr[1];
                        int i5 = i - 1;
                        System.arraycopy(iArr, 2, iArr, 0, i5);
                        iArr[i5] = 0;
                        iArr[i] = 0;
                        i--;
                    } else {
                        return new int[]{i2, nextSet, i3};
                    }
                } else {
                    i++;
                }
                iArr[i] = 1;
                z = !z;
            }
            nextSet++;
        }
        throw NotFoundException.getNotFoundInstance();
    }

    private static int decodeCode(BitArray bitArray, int[] iArr, int i) throws NotFoundException {
        recordPattern(bitArray, i, iArr);
        float f = MAX_AVG_VARIANCE;
        int i2 = -1;
        int i3 = 0;
        while (true) {
            int[][] iArr2 = CODE_PATTERNS;
            if (i3 >= iArr2.length) {
                break;
            }
            float patternMatchVariance = patternMatchVariance(iArr, iArr2[i3], MAX_INDIVIDUAL_VARIANCE);
            if (patternMatchVariance < f) {
                i2 = i3;
                f = patternMatchVariance;
            }
            i3++;
        }
        if (i2 >= 0) {
            return i2;
        }
        throw NotFoundException.getNotFoundInstance();
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Removed duplicated region for block: B:83:0x014a A[PHI: r19 
      PHI: (r19v10 boolean) = (r19v13 boolean), (r19v15 boolean) binds: [B:68:0x011c, B:42:0x00c4] A[DONT_GENERATE, DONT_INLINE]] */
    @Override // com.google.zxing.oned.OneDReader
    public Result decodeRow(int i, BitArray bitArray, Map<DecodeHintType, ?> map) throws NotFoundException, FormatException, ChecksumException {
        char c;
        boolean z;
        char c2;
        boolean z2;
        char c3;
        boolean z3;
        boolean z4 = false;
        boolean z5 = map != null && map.containsKey(DecodeHintType.ASSUME_GS1);
        int[] findStartPattern = findStartPattern(bitArray);
        int i2 = findStartPattern[2];
        ArrayList arrayList = new ArrayList(20);
        arrayList.add(Byte.valueOf((byte) i2));
        switch (i2) {
            case CODE_START_A /*{ENCODED_INT: 103}*/:
                c = 'e';
                break;
            case CODE_START_B /*{ENCODED_INT: 104}*/:
                c = 'd';
                break;
            case CODE_START_C /*{ENCODED_INT: 105}*/:
                c = 'c';
                break;
            default:
                throw FormatException.getFormatInstance();
        }
        StringBuilder sb = new StringBuilder(20);
        int[] iArr = new int[6];
        boolean z6 = true;
        int i3 = 0;
        boolean z7 = false;
        int i4 = 0;
        int i5 = 0;
        int i6 = i2;
        char c4 = c;
        boolean z8 = false;
        int i7 = findStartPattern[0];
        int i8 = findStartPattern[1];
        boolean z9 = false;
        while (!z8) {
            int decodeCode = decodeCode(bitArray, iArr, i8);
            arrayList.add(Byte.valueOf((byte) decodeCode));
            if (decodeCode != CODE_STOP) {
                z6 = true;
            }
            if (decodeCode != CODE_STOP) {
                i5++;
                i6 += i5 * decodeCode;
            }
            int i9 = i8;
            for (int i10 : iArr) {
                i9 += i10;
            }
            switch (decodeCode) {
                case CODE_START_A /*{ENCODED_INT: 103}*/:
                case CODE_START_B /*{ENCODED_INT: 104}*/:
                case CODE_START_C /*{ENCODED_INT: 105}*/:
                    throw FormatException.getFormatInstance();
                default:
                    switch (c4) {
                        case CODE_CODE_C /*{ENCODED_INT: 99}*/:
                            c2 = 'd';
                            if (decodeCode >= 100) {
                                if (decodeCode != CODE_STOP) {
                                    z6 = false;
                                }
                                if (decodeCode != CODE_STOP) {
                                    switch (decodeCode) {
                                        case 100:
                                            z = z4;
                                            c4 = 'd';
                                            z2 = false;
                                            break;
                                        case 101:
                                            z = z4;
                                            z2 = false;
                                            c4 = 'e';
                                            break;
                                        case CODE_FNC_1 /*{ENCODED_INT: 102}*/:
                                            if (z5) {
                                                if (sb.length() == 0) {
                                                    sb.append("]C1");
                                                } else {
                                                    sb.append((char) 29);
                                                }
                                            }
                                        default:
                                            z = z4;
                                            z2 = false;
                                            break;
                                    }
                                } else {
                                    z = z4;
                                    z2 = false;
                                    z8 = true;
                                    break;
                                }
                            } else {
                                if (decodeCode < 10) {
                                    sb.append('0');
                                }
                                sb.append(decodeCode);
                            }
                            z = z4;
                            z2 = false;
                        case 'd':
                            if (decodeCode < CODE_FNC_3) {
                                if (z4 == z7) {
                                    sb.append((char) (decodeCode + 32));
                                } else {
                                    sb.append((char) (decodeCode + 32 + 128));
                                }
                                z2 = false;
                                c2 = 'd';
                                z = false;
                                break;
                            } else {
                                if (decodeCode != CODE_STOP) {
                                    z6 = false;
                                }
                                if (decodeCode != CODE_STOP) {
                                    switch (decodeCode) {
                                        case CODE_FNC_3 /*{ENCODED_INT: 96}*/:
                                        case CODE_FNC_2 /*{ENCODED_INT: 97}*/:
                                        default:
                                            c3 = c4;
                                            break;
                                        case CODE_SHIFT /*{ENCODED_INT: 98}*/:
                                            z3 = z4;
                                            z2 = true;
                                            c3 = 'e';
                                            break;
                                        case CODE_CODE_C /*{ENCODED_INT: 99}*/:
                                            z3 = z4;
                                            z2 = false;
                                            c3 = 'c';
                                            break;
                                        case 100:
                                            if (z7 || !z4) {
                                                if (z7 && z4) {
                                                    c3 = c4;
                                                    z2 = false;
                                                    z7 = false;
                                                    z3 = false;
                                                    break;
                                                }
                                                c3 = c4;
                                                z2 = false;
                                                z3 = true;
                                                break;
                                            } else {
                                                c3 = c4;
                                                z2 = false;
                                                z7 = true;
                                                z3 = false;
                                            }
                                        case 101:
                                            z3 = z4;
                                            z2 = false;
                                            c3 = 'e';
                                            break;
                                        case CODE_FNC_1 /*{ENCODED_INT: 102}*/:
                                            if (z5) {
                                                if (sb.length() == 0) {
                                                    sb.append("]C1");
                                                } else {
                                                    sb.append((char) 29);
                                                }
                                            }
                                            c3 = c4;
                                            break;
                                    }
                                    z = z3;
                                    c4 = c3;
                                    c2 = 'd';
                                    break;
                                } else {
                                    c3 = c4;
                                    z8 = true;
                                }
                                z3 = z4;
                                z2 = false;
                                z = z3;
                                c4 = c3;
                                c2 = 'd';
                            }
                        case 'e':
                            if (decodeCode < 64) {
                                if (z4 == z7) {
                                    sb.append((char) (decodeCode + 32));
                                } else {
                                    sb.append((char) (decodeCode + 32 + 128));
                                }
                            } else if (decodeCode >= CODE_FNC_3) {
                                if (decodeCode != CODE_STOP) {
                                    z6 = false;
                                }
                                if (decodeCode != CODE_STOP) {
                                    switch (decodeCode) {
                                        case CODE_FNC_3 /*{ENCODED_INT: 96}*/:
                                        case CODE_FNC_2 /*{ENCODED_INT: 97}*/:
                                        default:
                                            c3 = c4;
                                            break;
                                        case CODE_SHIFT /*{ENCODED_INT: 98}*/:
                                            z3 = z4;
                                            z2 = true;
                                            c3 = 'd';
                                            break;
                                        case CODE_CODE_C /*{ENCODED_INT: 99}*/:
                                            break;
                                        case 100:
                                            z3 = z4;
                                            z2 = false;
                                            c3 = 'd';
                                            break;
                                        case 101:
                                            if (z7 || !z4) {
                                                if (z7 && z4) {
                                                    c3 = c4;
                                                    z2 = false;
                                                    z7 = false;
                                                    z3 = false;
                                                    break;
                                                }
                                                c3 = c4;
                                                z2 = false;
                                                z3 = true;
                                                break;
                                            } else {
                                                c3 = c4;
                                                z2 = false;
                                                z7 = true;
                                                z3 = false;
                                            }
                                        case CODE_FNC_1 /*{ENCODED_INT: 102}*/:
                                            if (z5) {
                                                if (sb.length() == 0) {
                                                    sb.append("]C1");
                                                } else {
                                                    sb.append((char) 29);
                                                }
                                            }
                                            c3 = c4;
                                            break;
                                    }
                                    z = z3;
                                    c4 = c3;
                                    c2 = 'd';
                                    break;
                                } else {
                                    c3 = c4;
                                    z8 = true;
                                }
                                z3 = z4;
                                z2 = false;
                                z = z3;
                                c4 = c3;
                                c2 = 'd';
                            } else if (z4 == z7) {
                                sb.append((char) (decodeCode - 64));
                            } else {
                                sb.append((char) (decodeCode + 64));
                            }
                            z2 = false;
                            c2 = 'd';
                            z = false;
                            break;
                        default:
                            c2 = 'd';
                            z = z4;
                            z2 = false;
                            break;
                    }
                    if (z9) {
                        c4 = c4 == 'e' ? c2 : 'e';
                    }
                    z9 = z2;
                    i7 = i8;
                    z4 = z;
                    i8 = i9;
                    i4 = decodeCode;
                    i3 = i4;
            }
        }
        int i11 = i8 - i7;
        int nextUnset = bitArray.getNextUnset(i8);
        if (!bitArray.isRange(nextUnset, Math.min(bitArray.getSize(), ((nextUnset - i7) / 2) + nextUnset), false)) {
            throw NotFoundException.getNotFoundInstance();
        } else if ((i6 - (i5 * i3)) % CODE_START_A == i3) {
            int length = sb.length();
            if (length != 0) {
                if (length > 0 && z6) {
                    if (c4 == CODE_CODE_C) {
                        sb.delete(length - 2, length);
                    } else {
                        sb.delete(length - 1, length);
                    }
                }
                float f = ((float) (findStartPattern[1] + findStartPattern[0])) / 2.0f;
                float f2 = ((float) i7) + (((float) i11) / 2.0f);
                int size = arrayList.size();
                byte[] bArr = new byte[size];
                for (int i12 = 0; i12 < size; i12++) {
                    bArr[i12] = ((Byte) arrayList.get(i12)).byteValue();
                }
                float f3 = (float) i;
                return new Result(sb.toString(), bArr, new ResultPoint[]{new ResultPoint(f, f3), new ResultPoint(f2, f3)}, BarcodeFormat.CODE_128);
            }
            throw NotFoundException.getNotFoundInstance();
        } else {
            throw ChecksumException.getChecksumInstance();
        }
    }
}
